/** Funciones basicas de NBF javascript */
var nbf = {};
//funciones de inicializacin
nbf.funcInit = [];

nbf.funcInitContenido = [];
nbf.funcInitCesta = [];
nbf.funcInitPrivada = [];

//manejadores globales de setTimeout y setInterval
nbf.tt = [];

/**
 * Incorpora la funcin pasada a la inicializacin del documento
 * @param function f Funcin
 */
nbf.ready = function(f){
	nbf.funcInit.push(f);
};

nbf.readyContenido = function(f){
	nbf.funcInitContenido.push(f);
}
nbf.readyCesta = function(f){
	nbf.funcInitCesta.push(f);
}

nbf.readyPrivada = function(f){
	nbf.funcInitPrivada.push(f);
} 

/**
 * Incorpora la funcin pasada a la inicializacin del documento
 * @param function f Funcin
 */
nbf.deviceReady = function(f){
	document.addEventListener("deviceready",f,false);
};

/**
 * Funcin para inicializar el DOM bajo un nodo jQuery
 * @param jQuery jq Objeto jQuery que se inicializar (junto con sus hijos) 
 */
nbf.init = function(jq){
	if(!jq)
		jq = $("body");
	for(var i=0;i<this.funcInit.length;i++){
		this.funcInit[i](jq);
	}
};
nbf.initContenido = function(jq2){
	//if(!jq)
		jq2 = $("contentPrincipal");
	for(var i=0;i<this.funcInitContenido.length;i++){
		this.funcInitContenido[i](jq2);
		//alert(this.funcInitContenido[0]);
	}
	// $(window).scrollTop(0);
};
nbf.initCesta = function (jq){
	jq = $("bloqueIzquierdo");
	for(var i=0;i<this.funcInitCesta.length;i++){
		this.funcInitCesta[i](jq);
		//alert(this.funcInitContenido[0]);
	}
}
nbf.initPrivada = function (jq){
	jq = $("bloqueDerecho");
	for(var i=0;i<this.funcInitPrivada.length;i++){
		this.funcInitPrivada[i](jq);
		//alert(this.funcInitContenido[0]);
	}
}


/**
 * Inicializa el jQuery UI
 * @param function funcionOk Funcin a ejecutar una vez cargado
 */
nbf.initJQueryUI = function(funcionOk,version){
	if(!version)
		version = "1.8.14";
	if(!nbf.objetoDefinido("$.ui")){
		nbf.cargarJs(
			"js/nbf/jquery-ui-"+version+".custom.min.js",
			function(){				
				if(funcionOk)
					funcionOk();
			}
		);
	}else{
		if(funcionOk)
			funcionOk();
	}	
};

/**
 * Obtiene la representacin JSON de un objeto
 * @param Object obj Objeto a representar
 * @returns string Cadena en formato JSON
 */
nbf.toJSON = function(obj){
	if($.isPlainObject(obj) || $.isArray(obj))
		return $.toJSON(obj);
	else 
		return obj;	
};

/**
 * Lee un contenido en JSON
 * @param string obj Cadena en formato JSON
 * @returns object Objeto generado (excepcin si falla)
 */
nbf.parseJSON = function(obj){
	/* implementacin anterior (falla en IE 7 en algunas expresiones, como fechas)
	 * try{
		return $.parseJSON(obj);
	}catch(e){
		return obj;
	}*/
	if(obj.indexOf("{")>-1 || obj.indexOf("[")>-1){
		try{
			return $.parseJSON(obj);
		}catch(e){
			return obj;
		}
	}else
		return obj;
};

/**
 * Lee unos parmetros en formato de formulario jQuery y crea un objeto
 * @param object valoresForm Valores del formulario (pares value, name)
 * @return object Objeto ledo 
 */
nbf.parseFormVals = function(valoresForm){
	var obj = {};
	for(var i in valoresForm)
		obj[valoresForm[i].name] = valoresForm[i].value;
	return obj;
};

/**
 * Carga el script JS pasado
 * @param string urlJs Script a cargar
 * @param function funcionRetorno Funcin a ejecutar si todo va bien
 */
nbf.cargarJs = function(urlJs,funcionRetorno){
    var script = document.createElement("script");
    script.setAttribute("type","text/javascript");    
    if(funcionRetorno){
        script.onreadystatechange = function(){
            if(this.readyState=='complete' || this.readyState=='loaded')
                funcionRetorno();
        };
        script.onload = funcionRetorno;
    }
    script.setAttribute("src",urlJs);
    document.getElementsByTagName("head")[0].appendChild(script);
};

/**
 * Determina si el objeto pasado est definido
 * @param string nombreObjeto Nombre del objeto a comprobar
 * @param string tipo Tipo a comprobar (por defecto "object")
 * @returns bool True si est definido, false en caso contrario
 */
nbf.objetoDefinido = function(nombreObjeto,tipo){
	if(!tipo)
        tipo = "object";
    return eval("(typeof "+nombreObjeto+").toLowerCase() == '"+tipo.toLowerCase()+"'");
};

/**
 * Codifica el dato pasado en un class
 * @param mixed dato Dato a codificar
 * @returns string Clase a usar
 */
nbf.codificarDatoClass = function(dato){
	return "d-"+$.base64Encode(nbf.toJSON(dato).toString()).replace(/=/g,"_")+"-d";
};

nbf.decodificarDatoClass = function (dato){
	return nbf.parseJSON($.base64Decode(dato.toString().replace(/-d$/,"").replace(/^d-/,"").replace(/_/g,"=")));
	
}
/**
 * Extrae los datos codificados en el class del elemento pasado
 * @param jQuery jqElem Elemento jQuery del que se leera su class
 * @returns object Datos ledos
 */
nbf.extraerDatos = function(jqElem){
	var classCss = jqElem.attr("class");
	var patron = /d\-[a-zA-Z0-9_]+\-d/;
	var coin = patron.exec(classCss);
	if(coin){
		var ret = nbf.parseJSON($.base64Decode(coin.toString().replace(/-d$/,"").replace(/^d-/,"").replace(/_/g,"=")));
		if(isNaN(ret))
			return ret;
		else
			return eval(ret);
	}
	return null;
};

/**
 * Genera un id aleatorio para aplicar sobre un elemento recien creado
 * @return string Id recien creado
 */
nbf.generarIdAleatorio = function(){
    var n = parseInt(Math.random()*1000000);
    while($("#nbf"+n).size()>0)
        n = parseInt(Math.random()*1000000);
    return "nbf"+n;
};

/**
 * Ejecuta en servidor la funcin pasada
 * @param string Funcin a ejecutar (ruta absoluta)
 * @param array Lista de parmetros de la funcin
 * @param function Funcin a ejecutar con la respuesta en caso de ok
 * @return jqXHR Peticin ajax recin realizada (permite abortarla, etc)  
 */
nbf.ejecutar = function(funcion,parametros,funcionOk){
	return nbf.ejecutarBase(funcion,parametros,true,funcionOk);
};

/**
 * Ejecuta en servidor la funcin pasada de forma sncrona
 * @param string Funcin a ejecutar (ruta absoluta)
 * @param array Lista de parmetros de la funcin
 * @return mixed Valor devuelto 
 */
nbf.ejecutarSync = function(funcion,parametros){
	return nbf.ejecutarBase(funcion,parametros,false);
};

//uso interno
nbf.ejecutarBase = function(funcion,parametros,async,funcionOk){
	
	//todas las funciones llevan un par mas de parametros que son idUsuario y sessId menos
	//ajaxLogin y ajaxRegistro
	if(funcion!="\\appv1\\app::ajaxLogin" && 
			funcion!="\\appv1\\app:ajaxRegistro" && 
			funcion!="\\appv1\\app:ajaxLoginFb" &&
			funcion!="\\appv1\\app:ajaxLoginFb2" &&
			funcion!="\\appv1\\app::ajaxValidarCodigoPostal" &&
			funcion!="\\appv1\\app::ajaxRestablecerPass" &&
			funcion!="\\appv1\\app::ajaxRestablecerPassValidarCodigo" &&
			funcion!="\\appv1\\app::ajaxCambiarPassSimple"){
		parametros.splice(0,0,st.obtenerLocalVar("idUsuario"),st.obtenerLocalVar("firma"),sessionStorage.getItem("sessId"));
	}
	
	var procesarRespuesta = function(respuesta){
		return nbf.parseJSON(respuesta);
	};
	var ret = $.ajax(
		{
			type: 'POST',
			async: async,
			url: nbf.raizUrl+"/app/pag/ajax-exec.php?"+Math.random(),
			data: {"func":funcion,"params":nbf.toJSON(parametros),"url":nbf.raizUrl}
		}
	);
	if(!async)
		return procesarRespuesta(ret.responseText);
	else{
		ret.success(
			function(data){
				var respuesta = procesarRespuesta(data);
				//if(respuesta && respuesta.status!="ok" && respuesta.sesionCaducada)
					//window.location = "login.html";
				if(funcionOk)
					funcionOk(respuesta);
			}
		);
		return ret;
	}
};

/**
 * Lanza la funcin pasada cuando hayan pasado X milisegundos (cancelando ejecuciones pendientes de esta funcion)
 * @param int milisegundos Milisegundos a esperar para lanzarla
 * @param function funcion Funcin a lanzar
 * @return int Valor retornado por setTimeout
 */
nbf.lanzar = function(milisegundos,funcion){
	if(nbf.tt[funcion])
		clearTimeout(nbf.tt[funcion]);
	nbf.tt[funcion] = setTimeout(
		function(){
			funcion();
		},
		milisegundos
	);
	return nbf.tt[funcion];
};

nbf.parseUrlParams = function(params){
	var asigs = params.split("&");
	var obj = {};
	for(var i=0;i<asigs.length;i++){
		var asig = asigs[i].split("=");
		obj[asig[0]] = asig[1];
	}
	return obj;
};

var tt2 = {};
nbf.lanzar2 = function (milisegundos,funcion,idProducto){
 var k = "p"+idProducto;
 if(tt2[k])
  clearTimeout(tt2[k]);
 tt2[k] = setTimeout(
  function(){
   funcion();
  },
  milisegundos
 );
 return tt2[k];
}

$(document).ready(
	function(){
		nbf.init();
		//nbf.initContenido();
	}
);
